==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/global_resources/translations/saverestoreplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>SaveRestore::Internal::SaveRestoreWidget</name>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.ui" line="20"/>
        <source>Save / Restore</source>
        <translation>Sauvegarde et restauration</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.ui" line="34"/>
        <source>Save your datas</source>
        <translation>Sauvegarder vos données</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.ui" line="47"/>
        <source>Restore your datas</source>
        <translation>Restaurer vos données</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.ui" line="62"/>
        <source>Export / Import</source>
        <translation>Exportation et importation</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.ui" line="79"/>
        <source>Export datas</source>
        <translation>Exporter vos données</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.ui" line="95"/>
        <source>Import datas</source>
        <translation>Importer des données</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="160"/>
        <source>Saving user&apos;s datas</source>
        <translation>Sauvegarde les données utilisateurs</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="160"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="174"/>
        <source>Saving user&apos;s datas : %1 (%2 Mo)</source>
        <translation>Sauvegarde des données utilisateurs : %1 (%2 Mo)</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="176"/>
        <source>Saving user&apos;s datas : %1 (%2 Ko)</source>
        <translation>Sauvegarde des données utilisateurs : %1 (%2 Ko)</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="228"/>
        <source>User&apos;s datas correctly saved into %1</source>
        <translation>Données utilisateurs correctement sauvegardées dans %1</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="229"/>
        <source>This archive can be used to restore your datas and settings.</source>
        <translation>Cette archive peut êetre utiliser pour restaurer les données et préférences.</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="231"/>
        <source>Error when trying to save user&apos;s datas into %1</source>
        <translation>Erreur lors de la tentative de sauvegarde des données dans %1</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="232"/>
        <source>This archive can not be used to restore your datas and settings.</source>
        <translation>Cette archive ne peut pas être utilisée pour restaurer vos données et préférences.</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="238"/>
        <source>Restore settings and datas from an archive. Application restart needed.</source>
        <translation>Restauration de vos données et préférences depuis votre archive. L&apos;application devra être redémarrée.</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="239"/>
        <source>The application must be restarted after the restoring process. All actual edition will be lost.
Do you really want to restore your settings and datas ?</source>
        <translation>L&apos;application doit être redémarrée après l&apos;étape de restauration. Toutes les éditions actuelles seront perdues.
Voulez-vous réellement restaurer vos données et préférences ?</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="245"/>
        <source>Select an archive</source>
        <translation>Sélectionnez une archive</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="259"/>
        <source>Unable to open the Zip archive %1. Error : %2.</source>
        <translation>Impossible d&apos;ouvrir l&apos;archive ZIP %1. Erreur : %2.</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="274"/>
        <source>Unable to get information about archived file. Error %1</source>
        <translation>Impossible de récupérer les données depuis l&apos;archive. Erreur %1</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="279"/>
        <source>This file (%1) is not a valid archive.</source>
        <translation>Ce fichier (%1) n&apos;est pas une archive valide.</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="342"/>
        <source>Your settings and datas are restored. Restart the application.</source>
        <translation>Vos données et préférences sont restaurées. Veuillez redémarrer l&apos;application.</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="343"/>
        <source>Your datas have been restored. The application will close know.</source>
        <translation>Vos données et préférences sont restaurées. L&apos;application va se fermer.</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="345"/>
        <source>Your settings and datas can not be restored. Restart the application.</source>
        <translation>Vos données et préférences ne pevent pas être restaurées. Veuillez redémarrer l&apos;application.</translation>
    </message>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="346"/>
        <source>Your datas can not be restored. The application will close know.</source>
        <translation>Vos données et préférences ne peuvent pas être restaurées. L&apos;application va se fermer.</translation>
    </message>
</context>
<context>
    <name>SaveRestore::SaveRestorePage</name>
    <message>
        <location filename="../../plugins/saverestoreplugin/saverestorepage.cpp" line="73"/>
        <source>Save / Restore / Import / Export user&apos;s datas</source>
        <translation>Sauvegarde / Restauration / Importation / Exportation</translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.8.0.orig.tar.gz: freemedforms-0.8.0/global_resources/translations/saverestoreplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>SaveRestore::Internal::SaveRestoreWidget</name>
    <message>
        <source>Save / Restore</source>
        <translation>Sauvegarde et restauration</translation>
    </message>
    <message>
        <source>Save your datas</source>
        <translation>Sauvegarder vos données</translation>
    </message>
    <message>
        <source>Restore your datas</source>
        <translation>Restaurer vos données</translation>
    </message>
    <message>
        <source>Export / Import</source>
        <translation>Exportation et importation</translation>
    </message>
    <message>
        <source>Export datas</source>
        <translation>Exporter vos données</translation>
    </message>
    <message>
        <source>Import datas</source>
        <translation>Importer des données</translation>
    </message>
    <message>
        <source>Saving user&apos;s datas</source>
        <translation>Sauvegarde les données utilisateurs</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Saving user&apos;s datas : %1 (%2 Mo)</source>
        <translation>Sauvegarde des données utilisateurs : %1 (%2 Mo)</translation>
    </message>
    <message>
        <source>Saving user&apos;s datas : %1 (%2 Ko)</source>
        <translation>Sauvegarde des données utilisateurs : %1 (%2 Ko)</translation>
    </message>
    <message>
        <source>User&apos;s datas correctly saved into %1</source>
        <translation>Données utilisateurs correctement sauvegardées dans %1</translation>
    </message>
    <message>
        <source>This archive can be used to restore your datas and settings.</source>
        <translation>Cette archive peut êetre utiliser pour restaurer les données et préférences.</translation>
    </message>
    <message>
        <source>Error when trying to save user&apos;s datas into %1</source>
        <translation>Erreur lors de la tentative de sauvegarde des données dans %1</translation>
    </message>
    <message>
        <source>This archive can not be used to restore your datas and settings.</source>
        <translation>Cette archive ne peut pas être utilisée pour restaurer vos données et préférences.</translation>
    </message>
    <message>
        <source>Restore settings and datas from an archive. Application restart needed.</source>
        <translation>Restauration de vos données et préférences depuis votre archive. L&apos;application devra être redémarrée.</translation>
    </message>
    <message>
        <source>The application must be restarted after the restoring process. All actual edition will be lost.
Do you really want to restore your settings and datas ?</source>
        <translation>L&apos;application doit être redémarrée après l&apos;étape de restauration. Toutes les éditions actuelles seront perdues.
Voulez-vous réellement restaurer vos données et préférences ?</translation>
    </message>
    <message>
        <source>Select an archive</source>
        <translation>Sélectionnez une archive</translation>
    </message>
    <message>
        <source>Unable to open the Zip archive %1. Error : %2.</source>
        <translation>Impossible d&apos;ouvrir l&apos;archive ZIP %1. Erreur : %2.</translation>
    </message>
    <message>
        <source>Unable to get information about archived file. Error %1</source>
        <translation>Impossible de récupérer les données depuis l&apos;archive. Erreur %1</translation>
    </message>
    <message>
        <source>This file (%1) is not a valid archive.</source>
        <translation>Ce fichier (%1) n&apos;est pas une archive valide.</translation>
    </message>
    <message>
        <source>Your settings and datas are restored. Restart the application.</source>
        <translation>Vos données et préférences sont restaurées. Veuillez redémarrer l&apos;application.</translation>
    </message>
    <message>
        <source>Your datas have been restored. The application will close know.</source>
        <translation>Vos données et préférences sont restaurées. L&apos;application va se fermer.</translation>
    </message>
    <message>
        <source>Your settings and datas can not be restored. Restart the application.</source>
        <translation>Vos données et préférences ne pevent pas être restaurées. Veuillez redémarrer l&apos;application.</translation>
    </message>
    <message>
        <source>Your datas can not be restored. The application will close know.</source>
        <translation>Vos données et préférences ne peuvent pas être restaurées. L&apos;application va se fermer.</translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveRestore::SaveRestorePage</name>
    <message>
        <source>Save / Restore / Import / Export user&apos;s datas</source>
        <translation>Sauvegarde / Restauration / Importation / Exportation</translation>
    </message>
</context>
</TS>
